{
  config,
  lib,
  pkgs,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  pub-solar.graphical.enable = true;
  pub-solar.sway.enable = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  pub-solar.paranoia.enable = true;
  pub-solar.core.hibernation.resumeDevice = "/dev/dm-0";
  pub-solar.core.hibernation.resumeOffset = 15296512;

  hardware.cpu.intel.updateMicrocode = true;

  networking.networkmanager.wifi.backend = mkForce "wpa_supplicant";

  services.printing.drivers = [
    pkgs.cups-brother-hl3140cw
  ];

  home-manager = with pkgs;
    pkgs.lib.setAttrByPath ["users" psCfg.user.name] {
      xdg.configFile = mkIf psCfg.sway.enable {
        "sway/config.d/10-screens.conf".source = ./.config/sway/config.d/screens.conf;
        "sway/config.d/10-autostart.conf".source = ./.config/sway/config.d/autostart.conf;
        "sway/config.d/10-input-defaults.conf".source = ./.config/sway/config.d/input-defaults.conf;
        "sway/config.d/10-custom-keybindings.conf".source = ./.config/sway/config.d/custom-keybindings.conf;
      };

      home.packages = [
        inkscape
      ];
    };

  # For OpenProject development with https
  security.pki.certificates = [
    (builtins.readFile ./step-roots.pem)
  ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?
}
