{
  config,
  pkgs,
  lib,
  flake,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  boot.loader.systemd-boot.enable = lib.mkForce false;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
  };
  boot.loader.efi.canTouchEfiVariables = true;

  hardware.cpu.intel.updateMicrocode = true;

  pub-solar.core.disk-encryption-active = false;
  pub-solar.core.lite = true;

  security.sudo.extraRules = [
    {
      users = ["${psCfg.user.name}"];
      commands = [
        {
          command = "ALL";
          options = ["NOPASSWD"];
        }
      ];
    }
  ];

  services.ddclient = {
    enable = false;
    ipv6 = true;
    domains = ["backup.b12f.io"];
    server = "ddns.hosting.de";
    username = "b12f";
    use = "web, web=https://ipcheck-ds.wieistmeineip.de/callback/, web-skip='ip\":\"'";
    passwordFile = "/run/agenix/dyndns-droppie.key";
  };

  age.secrets."dyndns-droppie.key" = {
    file = "${flake.self}/secrets/dyndns-droppie.key";
    mode = "400";
    owner = "root";
  };

  # ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBZQSephFJU0NMbVbhwvVJ2/m6jcPYo1IsWCsoarqKin root@droppie
  age.secrets."droppie-ssh-root.key" = {
    file = "${flake.self}/secrets/droppie-ssh-root.key";
    path = "/home/${psCfg.user.name}/.ssh/id_ed25519";
    mode = "400";
    owner = psCfg.user.name;
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?
}
