{ pkgs, adblock-unbound, ... }:
{
  networking.firewall.allowedUDPPorts = [ 67 ];

  services.kea.dhcp4 = {
    enable = true;
    settings = {
      interfaces-config = {
        dhcp-socket-type = "raw";
        interfaces = [
          "enabcm6e4ei0"
          "wlan0"
        ];
      };

      lease-database = {
        name = "/var/lib/kea/dhcp4.leases";
        persist = true;
        type = "memfile";
      };

      rebind-timer = 2000;
      renew-timer = 1000;
      valid-lifetime = 4000;

      subnet4 = [
        {
          subnet = "192.168.178.0/24";
          pools = [
            { pool = "192.168.178.2 - 192.168.178.255"; }
          ];

          option-data = [
            {
              name = "domain-name-servers";
              space = "dhcp4";
              csv-format = true;
              data = "192.168.178.2";
              always-send = true;
            }
            {
              name = "routers";
              data = "192.168.178.1";
              always-send = true;
            }
          ];

          reservations = [
            {
              hostname = "droppie.local";
              hw-address = "08:f1:ea:97:0f:0c";
              ip-address = "192.168.178.3";
            }
            {
              hostname = "pie.local";
              hw-address = "dc:a6:32:5c:31:64";
              ip-address = "192.168.178.2";
            }
          ];
        }
      ];
    };
  };

  services.kea.dhcp6 = {
    enable = true;
    settings = {
      interfaces-config = {
        dhcp-socket-type = "raw";
        interfaces = [
          "enabcm6e4ei0"
          "wlan0"
        ];
      };
      lease-database = {
        name = "/var/lib/kea/dhcp6.leases";
        persist = true;
        type = "memfile";
      };
      rebind-timer = 2000;
      renew-timer = 1000;
    };
  };
}
