{
  config,
  pkgs,
  lib,
  flake,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  imports = [
    ./session-variables.nix
    ./concepts-and-training.nix
  ];

  home-manager = pkgs.lib.setAttrByPath ["users" psCfg.user.name] {
    home.packages = with pkgs; [
      present-md
      inkscape
      gpxsee
      digikam
      nix-output-monitor
      tigervnc
      nodejs
      solaar
      insomnia
      concourse
    ];

    programs.ssh = {
      enable = true;
      matchBlocks = {
        "pie.local" = {
          hostname = "pie.local";
          user = "yule";
        };

        "git.b12f.io" = {
          hostname = "git.b12f.io";
          user = "git";
          port = 2222;
        };

        "aur.archlinux.org" = {
          user = "aur";
        };

        "leavieler.art" = {
          hostname = "web5svsvy.wh.hosting.zone";
          user = "web5svsvy_cgzqa3";
          port = 2244;
        };

        "benjaminbaedorf.eu" = {
          hostname = "web5svsvy.wh.hosting.zone";
          user = "web5svsvy_cgzqa3";
          port = 2244;
        };

        "miom.space" = {
          hostname = "web7dgkba.wh.hosting.zone";
          user = "web7dgkba_c9em8f";
          port = 2244;
        };

        "latenight.blue" = {
          hostname = "latenight.blue";
          user = "lnb";
          extraOptions = {
            MACs = "hmac-sha2-512-etm@openssh.com";
          };
        };

        "blacktea.io" = {
          hostname = "latenight.blue";
          user = "lnb";
          extraOptions = {
            MACs = "hmac-sha2-512-etm@openssh.com";
          };
        };

        "laurakirst.de" = {
          hostname = "webj4bsux.wh.hosting.zone";
          user = "webj4bsux_36qkrk";
          port = 2244;
        };
      };
    };

    xdg.configFile."mutt/accounts.muttrc".text = ''
      source ./hello@benjaminbaedorf.eu.muttrc

      macro index <f1> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/hello@benjaminbaedorf.eu.muttrc<enter><change-folder>!<enter>'
      macro index <f2> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/benjamin.baedorf@rwth-aachen.de.muttrc<enter><change-folder>!<enter>'
      macro index <f3> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/b.baedorf@openproject.com.muttrc<enter><change-folder>!<enter>'
      macro index <f4> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/byb@miom.space.muttrc<enter><change-folder>!<enter>'
      macro index <f5> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/mail@b12f.io.muttrc<enter><change-folder>!<enter>'
      macro index <f6> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/admins@pub.solar.muttrc<enter><change-folder>!<enter>'
      macro index <f7> '<sync-mailbox><enter-command>source $XDG_CONFIG_HOME/mutt/crew@pub.solar.muttrc<enter><change-folder>!<enter>'
    '';
    xdg.configFile."mutt/hello@benjaminbaedorf.eu.muttrc".source = ./.config/mutt + "/hello@benjaminbaedorf.eu.muttrc";
    xdg.configFile."mutt/benjamin.baedorf@rwth-aachen.de.muttrc".source = ./.config/mutt + "/benjamin.baedorf@rwth-aachen.de.muttrc";
    xdg.configFile."mutt/hello@benjaminbaedorf.eu.signature".source = ./.config/mutt + "/hello@benjaminbaedorf.eu.signature";
    xdg.configFile."mutt/b.baedorf@openproject.com.muttrc".source = ./.config/mutt + "/b.baedorf@openproject.com.muttrc";
    xdg.configFile."mutt/b.baedorf@openproject.com.signature".source = ./.config/mutt + "/b.baedorf@openproject.com.signature";
    xdg.configFile."mutt/byb@miom.space.muttrc".source = ./.config/mutt + "/byb@miom.space.muttrc";
    xdg.configFile."mutt/byb@miom.space.signature".source = ./.config/mutt + "/byb@miom.space.signature";
    xdg.configFile."mutt/mail@b12f.io.muttrc".source = ./.config/mutt + "/mail@b12f.io.muttrc";
    xdg.configFile."mutt/mail@b12f.io.signature".source = ./.config/mutt + "/mail@b12f.io.signature";
    xdg.configFile."mutt/admins@pub.solar.muttrc".source = ./.config/mutt + "/admins@pub.solar.muttrc";
    xdg.configFile."mutt/admins@pub.solar.signature".source = ./.config/mutt + "/admins@pub.solar.signature";
    xdg.configFile."mutt/crew@pub.solar.muttrc".source = ./.config/mutt + "/crew@pub.solar.muttrc";
    xdg.configFile."mutt/crew@pub.solar.signature".source = ./.config/mutt + "/crew@pub.solar.signature";
    xdg.configFile."offlineimap/config".source = ./.config/offlineimap/config;
    xdg.configFile."msmtp/config".source = ./.config/msmtp/config;
    # xdg.configFile."wallpaper.jpg".source = ./assets/wallpaper.jpg;

    programs.bash.initExtra = ''
      source ${config.age.secrets.b12f-env-secrets.path}
    '';
  };

  age.secrets."mopidy.conf" = {
    file = "${flake.self}/secrets/mopidy.conf";
    mode = "700";
    owner = "b12f";
  };
  services.mopidy.extraConfigFiles = ["/run/agenix/mopidy.conf"];

  programs.ssh.extraConfig = "
    PubkeyAcceptedKeyTypes +ssh-rsa
  ";
}
